@@ -1,34 +1,50 @@
 import logging
-import os
 import traceback
+from packaging import version
 from typing import Tuple
 import warnings
 
+DEFAULT_VERSION = "0.0.0"
+
 try:
     from ._version import version as __version__
 except ImportError:
-    __version__ = "0.0.0"
+    __version__ = DEFAULT_VERSION
 
 
-def _parse_version(version: str) -> Tuple[int, ...]:
+def _parse_version(input_version: str) -> Tuple[int, int, bool]:
     """
     Takes a string which starts with standard major.minor.patch.
     and returns the split of major and minor version as integers
 
     Parameters
     ----------
-    version: str
+    input_version: str
         The semantic version string
 
     Returns
     -------
-    Tuple[int, int]
-        major and minor versions
+    Tuple[int, int, bool]
+        major and minor versions, and flag "is this unstable version?"
     """
-    return tuple(int(i) for i in version.split(".")[:2])
+    parsed_version = version.parse(input_version)
+    result: Tuple[int, int, bool] = (0, 0, True)
+    if isinstance(parsed_version, version.Version):
+        is_unstable = parsed_version.is_devrelease or parsed_version.is_prerelease
+        result = parsed_version.major, parsed_version.minor, is_unstable
+    else:
+        try:
+            split_version = input_version.split(".")[:2]
+            major, minor = int(split_version[0]), int(split_version[1])
+        except ValueError:
+            raise ValueError("Malformed version %s" % input_version)
+        result = major, minor, True
+    if input_version == DEFAULT_VERSION:
+        return result[0], result[1], True
+    return result
 
 
-MAJOR_VERSION, MINOR_VERSION = _parse_version(__version__)
+MAJOR_VERSION, MINOR_VERSION, IS_UNSTABLE_VERSION = _parse_version(__version__)
 
 try:
     # FIXME(https://github.com/abseil/abseil-py/issues/99)
@@ -50,4 +66,3 @@ try:
 
 except Exception:
     warnings.warn(f"Failed to fix absl logging bug {traceback.format_exc()}")
-    pass
