@@ -14,6 +14,7 @@ from typing import Union, Optional, Dict, Any, Tuple, Type, List, Callable
 import pandas as pd
 import numpy as np
 import tensorflow as tf
+import xarray as xr
 
 import sklearn
 from sklearn.base import BaseEstimator, TransformerMixin
@@ -22,7 +23,13 @@ from sklearn.model_selection import BaseCrossValidator, cross_validate
 from sklearn.pipeline import Pipeline
 
 from gordo.util import disk_registry
-from gordo import serializer, __version__, MAJOR_VERSION, MINOR_VERSION
+from gordo import (
+    serializer,
+    __version__,
+    MAJOR_VERSION,
+    MINOR_VERSION,
+    IS_UNSTABLE_VERSION,
+)
 from gordo_dataset.dataset import _get_dataset
 from gordo.machine.model.base import GordoBase
 from gordo.machine.model.utils import metric_wrapper
@@ -52,6 +59,8 @@ class ModelBuilder:
         -------
         >>> from gordo_dataset.sensor_tag import SensorTag
         >>> from gordo.machine import Machine
+        >>> from gordo.dependencies import configure_once
+        >>> configure_once()
         >>> machine = Machine(
         ...     name="special-model-name",
         ...     model={"sklearn.decomposition.PCA": {"svd_solver": "auto"}},
@@ -431,6 +440,8 @@ class ModelBuilder:
         int
             The difference between X and the model's output lengths.
         """
+        if isinstance(X, pd.DataFrame) or isinstance(X, xr.DataArray):
+            X = X.values
         out = model.predict(X) if hasattr(model, "predict") else model.transform(X)
         return len(X) - len(out)
 
@@ -536,6 +547,8 @@ class ModelBuilder:
                 -------
                 >>> from gordo.machine import Machine
                 >>> from gordo_dataset.sensor_tag import SensorTag
+                >>> from gordo.dependencies import configure_once
+                >>> configure_once()
                 >>> machine = Machine(
                 ...     name="special-model-name",
                 ...     model={"sklearn.decomposition.PCA": {"svd_solver": "auto"}},
@@ -555,6 +568,7 @@ class ModelBuilder:
         # Sets a lot of the parameters to json.dumps explicitly to ensure that we get
         # consistent hash-values even if json.dumps changes their default values
         # (and as such might generate different json which again gives different hash)
+        gordo_version = __version__ if IS_UNSTABLE_VERSION else ""
         json_rep = json.dumps(
             {
                 "name": machine.name,
@@ -563,6 +577,7 @@ class ModelBuilder:
                 "evaluation_config": machine.evaluation,
                 "gordo-major-version": MAJOR_VERSION,
                 "gordo-minor-version": MINOR_VERSION,
+                "gordo_version": gordo_version,
             },
             sort_keys=True,
             default=str,
