@@ -28,6 +28,7 @@ from gordo.machine import Machine
 from gordo.cli.workflow_generator import workflow_cli
 from gordo.cli.custom_types import key_value_par, HostIP
 from gordo.reporters.exceptions import ReporterException
+from gordo.dependencies import configure_once
 
 from .exceptions_reporter import ReportLevel, ExceptionsReporter
 
@@ -74,6 +75,8 @@ def gordo(gordo_ctx: click.Context, **ctx):
 
     gordo_ctx.obj = gordo_ctx.params
 
+    configure_once()
+
 
 @click.command()
 @click.argument("machine-config", envvar="MACHINE", type=yaml.safe_load)
