@@ -3,18 +3,19 @@ import time
 import pkg_resources
 import os
 
-from typing import Dict, Any, TypeVar, Type, List
+from typing import Dict, Any, TypeVar, Type, List, Tuple, cast
 
 import click
 import json
+from jinja2 import Environment, BaseLoader
 
 from pydantic import parse_obj_as, ValidationError
 from gordo import __version__
 from gordo.workflow.config_elements.normalized_config import NormalizedConfig
-from gordo.workflow.config_elements.schemas import CustomEnv
 from gordo.workflow.workflow_generator import workflow_generator as wg
 from gordo.cli.exceptions_reporter import ReportLevel
 from gordo.util.version import parse_version
+from gordo.dependencies import configure_once
 
 
 logger = logging.getLogger(__name__)
@@ -23,6 +24,13 @@ logger = logging.getLogger(__name__)
 PREFIX = "WORKFLOW_GENERATOR"
 DEFAULT_BUILDER_EXCEPTIONS_REPORT_LEVEL = ReportLevel.TRACEBACK
 
+ML_SERVER_HPA_TYPES = ["none", "k8s_cpu", "keda"]
+DEFAULT_ML_SERVER_HPA_TYPE = "k8s_cpu"
+
+DEFAULT_KEDA_PROMETHEUS_METRIC_NAME = "gordo_server_request_duration_seconds_count"
+DEFAULT_KEDA_PROMETHEUS_QUERY = 'sum(rate(gordo_server_request_duration_seconds_count{project=~"{{project_name}}",path=~".*prediction"}[30s]))'
+DEFAULT_KEDA_PROMETHEUS_THRESHOLD = "1.0"
+
 
 def get_builder_exceptions_report_level(config: NormalizedConfig) -> ReportLevel:
     orig_report_level = None
@@ -83,6 +91,50 @@ DEFAULT_CUSTOM_MODEL_BUILDER_ENVS = """
 """
 
 
+def validate_generate_context(context):
+    if context["ml_server_hpa_type"] == "keda":
+        if not context["with_keda"]:
+            raise click.ClickException(
+                '"--ml-server-hpa-type=keda" is only be supported with "--with-keda" flag'
+            )
+        if not context["prometheus_server_address"]:
+            raise click.ClickException(
+                '--prometheus-server-address should be specified for "--ml-server-hpa-type=keda"'
+            )
+
+
+KEDA_PROMETHEUS_QUERY_ARGS = ["project_name"]
+
+
+def prepare_keda_prometheus_query(context):
+    keda_prometheus_query = context["keda_prometheus_query"]
+    if keda_prometheus_query:
+        template = Environment(loader=BaseLoader).from_string(keda_prometheus_query)
+        kwargs = {k: context[k] for k in KEDA_PROMETHEUS_QUERY_ARGS}
+        return template.render(**kwargs)
+
+
+def prepare_resources_labels(value: str) -> List[Tuple[str, Any]]:
+    resources_labels: List[Tuple[str, Any]] = []
+    if value:
+        try:
+            json_value = json.loads(value)
+        except json.JSONDecodeError as e:
+            raise click.ClickException(
+                '"--resources-labels=%s" contains invalid JSON value: %s'
+                % (value, str(e))
+            )
+        if isinstance(json_value, dict):
+            resources_labels = cast(List[Tuple[str, Any]], list(json_value.items()))
+        else:
+            type_name = type(json_value).__name__
+            raise click.ClickException(
+                '"--resources-labels=%s" contains value with type "%s" instead "dict"'
+                % (value, type_name)
+            )
+    return resources_labels
+
+
 @click.group("workflow")
 @click.pass_context
 def workflow_cli(gordo_ctx):
@@ -224,18 +276,76 @@ def workflow_cli(gordo_ctx):
     help="Default imagePullPolicy for all gordo's images",
     envvar=f"{PREFIX}_IMAGE_PULL_POLICY",
 )
+@click.option(
+    "--with-keda",
+    is_flag=True,
+    help="Enable support for the KEDA autoscaler",
+    envvar=f"{PREFIX}_WITH_KEDA",
+)
+@click.option(
+    "--ml-server-hpa-type",
+    help="HPA type for the ML server",
+    envvar=f"{PREFIX}_ML_SERVER_HPA_TYPE",
+    type=click.Choice(ML_SERVER_HPA_TYPES),
+    default=DEFAULT_ML_SERVER_HPA_TYPE,
+)
 @click.option(
     "--custom-model-builder-envs",
     help="List of custom environment variables in ",
     envvar=f"{PREFIX}_CUSTOM_MODEL_BUILDER_ENVS",
     default=DEFAULT_CUSTOM_MODEL_BUILDER_ENVS,
 )
+@click.option(
+    "--prometheus-server-address",
+    help='Prometheus url. Required for "--ml-server-hpa-type=keda"',
+    envvar=f"{PREFIX}_PROMETHEUS_SERVER_ADDRESS",
+)
+@click.option(
+    "--keda-prometheus-metric-name",
+    help="metricName value for the KEDA prometheus scaler",
+    envvar=f"{PREFIX}_KEDA_PROMETHEUS_METRIC_NAME",
+    default=DEFAULT_KEDA_PROMETHEUS_METRIC_NAME,
+)
+@click.option(
+    "--keda-prometheus-query",
+    help="query value for the KEDA prometheus scaler",
+    envvar=f"{PREFIX}_KEDA_PROMETHEUS_QUERY",
+    default=DEFAULT_KEDA_PROMETHEUS_QUERY,
+)
+@click.option(
+    "--keda-prometheus-threshold",
+    help="threshold value for the KEDA prometheus scaler",
+    envvar=f"{PREFIX}_KEDA_PROMETHEUS_THRESHOLD",
+    default=DEFAULT_KEDA_PROMETHEUS_THRESHOLD,
+)
+@click.option(
+    "--resources-labels",
+    help="Additional labels for resources. Have to be empty string or a dictionary in JSON format",
+    envvar=f"{PREFIX}_RESOURCE_LABELS",
+    default="",
+)
+@click.option(
+    "--server-termination-grace-period",
+    help="terminationGracePeriodSeconds for the gordo server",
+    envvar=f"{PREFIX}_SERVER_TERMINATION_GRACE_PERIOD",
+    type=int,
+    default=60,
+)
+@click.option(
+    "--server-target-cpu-utilization-percentage",
+    help="targetCPUUtilizationPercentage for gordo-server's HPA",
+    envvar=f"{PREFIX}_SERVER_TARGET_CPU_UTILIZATION_PERCENTAGE",
+    type=int,
+    default=50,
+)
 @click.pass_context
 def workflow_generator_cli(gordo_ctx, **ctx):
     """
     Machine Configuration to Argo Workflow
     """
 
+    configure_once()
+
     context: Dict[Any, Any] = ctx.copy()
     yaml_content = wg.get_dict_from_yaml(context["machine_config"])
 
@@ -247,15 +357,19 @@ def workflow_generator_cli(gordo_ctx, **ctx):
     logging.getLogger("gordo").setLevel(log_level.upper())
     context["log_level"] = log_level.upper()
 
-    # Create normalized config
-    config = NormalizedConfig(yaml_content, project_name=context["project_name"])
+    validate_generate_context(context)
 
+    context["resources_labels"] = prepare_resources_labels(context["resources_labels"])
+
+    model_builder_env = None
     if context["custom_model_builder_envs"]:
-        result = parse_json(context["custom_model_builder_envs"], List[CustomEnv])
-        custom_model_builder_envs = []
-        for value in result:
-            custom_model_builder_envs.append(value.dict(exclude_defaults=True))
-        context["custom_model_builder_envs"] = custom_model_builder_envs
+        model_builder_env = json.loads(context["custom_model_builder_envs"])
+    # Create normalized config
+    config = NormalizedConfig(
+        yaml_content,
+        project_name=context["project_name"],
+        model_builder_env=model_builder_env,
+    )
 
     version = parse_version(context["gordo_version"])
     if "image_pull_policy" not in context or not context["image_pull_policy"]:
@@ -270,8 +384,13 @@ def workflow_generator_cli(gordo_ctx, **ctx):
         context.pop("n_servers") or len(config.machines) * 10
     )
 
+    context["volumes"] = None
+    if "volumes" in config.globals["runtime"]:
+        context["volumes"] = config.globals["runtime"]["volumes"]
+
+    builder_runtime = config.globals["runtime"]["builder"]
     # We know these exist since we set them in the default globals
-    builder_resources = config.globals["runtime"]["builder"]["resources"]
+    builder_resources = builder_runtime["resources"]
     context["model_builder_resources_requests_memory"] = builder_resources["requests"][
         "memory"
     ]
@@ -282,9 +401,10 @@ def workflow_generator_cli(gordo_ctx, **ctx):
         "memory"
     ]
     context["model_builder_resources_limits_cpu"] = builder_resources["limits"]["cpu"]
-
     context["model_builder_image"] = config.globals["runtime"]["builder"]["image"]
 
+    context["builder_runtime"] = builder_runtime
+
     context["server_resources"] = config.globals["runtime"]["server"]["resources"]
     context["server_image"] = config.globals["runtime"]["server"]["image"]
 
@@ -333,6 +453,8 @@ def workflow_generator_cli(gordo_ctx, **ctx):
 
     context["postgres_host"] = f"gordo-postgres-{config.project_name}"
 
+    context["keda_prometheus_query"] = prepare_keda_prometheus_query(context)
+
     # If enabling influx, we setup a postgres reporter to send metadata
     # to allowing querying about the machine from grafana
     if enable_influx:
@@ -405,35 +527,7 @@ def workflow_generator_cli(gordo_ctx, **ctx):
         project_workflow += 1
 
 
-@click.command("unique-tags")
-@click.option(
-    "--machine-config", type=str, required=True, help="Machine configuration file"
-)
-@click.option(
-    "--output-file-tag-list",
-    type=str,
-    required=False,
-    help="Optional file to dump list of unique tags",
-)
-def unique_tag_list_cli(machine_config: str, output_file_tag_list: str):
-
-    yaml_content = wg.get_dict_from_yaml(machine_config)
-
-    machines = NormalizedConfig(yaml_content, project_name="test-proj-name").machines
-
-    tag_list = set(tag for machine in machines for tag in machine.dataset.tag_list)
-
-    if output_file_tag_list:
-        with open(output_file_tag_list, "w") as output_file:
-            for tag in tag_list:
-                output_file.write(f"{tag.name}\n")
-    else:
-        for tag in tag_list:
-            print(tag.name)
-
-
 workflow_cli.add_command(workflow_generator_cli)
-workflow_cli.add_command(unique_tag_list_cli)
 
 if __name__ == "__main__":
     workflow_cli()
