@@ -20,6 +20,7 @@ from flask import Flask, g, request, current_app, make_response, jsonify
 from typing import Optional, Any, Dict
 
 from gordo.server import views
+from gordo.dependencies import configure_once
 from gordo import __version__
 
 from prometheus_client import CollectorRegistry
@@ -142,6 +143,8 @@ def build_app(
     """
     Build app and any associated routes
     """
+    configure_once()
+
     app = Flask(__name__)
     app.config.from_object(Config())
     if config is not None:
