@@ -1,5 +1,5 @@
-"""Tests for gordo.client."""
-# TODO: Move those tests to gordo.client project.
+"""Tests for gordo-client."""
+# TODO: Move those tests to gordo-client project.
 
 import json
 import logging
@@ -13,24 +13,24 @@ import pytest
 import requests
 from click.testing import CliRunner
 from dateutil.parser import isoparse  # type: ignore
-from gordo.client import Client, utils as client_utils
-from gordo.client.forwarders import ForwardPredictionsIntoInflux
-from gordo.client.io import (
+from gordo_client import Client, utils as client_utils
+from gordo_client.forwarders import ForwardPredictionsIntoInflux
+from gordo_client.io import (
     _handle_response,
     HttpUnprocessableEntity,
     BadGordoRequest,
     NotFound,
     ResourceGone,
 )
-from gordo.client.schemas import Machine as ClientMachine
-from gordo.client.utils import PredictionResult
+from gordo_client.schemas import Machine as ClientMachine
+from gordo_client.utils import PredictionResult
 from gordo_dataset.data_provider import providers
 from gordo_dataset.datasets import TimeSeriesDataset
 from mock import patch, call
 from sklearn.base import BaseEstimator
 
 from gordo import serializer
-from gordo.client.cli.client import gordo_client
+from gordo_client.cli.client import gordo_client
 from gordo.machine import Machine
 from gordo.machine.model import utils as model_utils
 from gordo.server import utils as server_utils
@@ -49,23 +49,6 @@ def test_client_get_metadata(gordo_project, ml_server):
     assert client.get_metadata().get("no-such-target", None) is None
 
 
-def test_client_get_dataset(gordo_project, metadata, ml_server):
-    data_provider = providers.RandomDataProvider(min_size=10)
-    client = Client(project=gordo_project, data_provider=data_provider)
-    start = isoparse("2016-01-01T00:00:00+00:00")
-    end = isoparse("2016-01-01T12:00:00+00:00")
-    machine = Machine(**metadata)
-    assert type(machine.dataset) is TimeSeriesDataset
-    machine.dataset.row_filter_buffer_size = 12
-    machine.dataset.n_samples_threshold = 10
-    client_machine = ClientMachine(**machine.to_dict())
-    dataset = client._get_dataset(client_machine, start, end)
-    assert dataset.row_filter_buffer_size == 0
-    assert dataset.n_samples_threshold == 0
-    assert dataset.low_threshold is None
-    assert dataset.high_threshold is None
-
-
 def test_client_predict_specific_targets(gordo_project, gordo_single_target, ml_server):
     """
     Client.predict should filter any endpoints given to it.
@@ -344,11 +327,7 @@ def test_client_cli_predict(
     )
 
     # Run without any error
-    with patch(
-        "gordo_dataset.sensor_tag._asset_from_tag_name",
-        side_effect=lambda *args, **kwargs: "default",
-    ):
-        out = runner.invoke(gordo_client, args=args)
+    out = runner.invoke(gordo_client, args=args)
     assert out.exit_code == 0, f"{out.output}"
 
     # If we activated forwarder and we had any actual data then there should
@@ -406,11 +385,7 @@ def test_client_cli_predict_non_zero_exit(
 
     # Run without any error
     with caplog.at_level(logging.CRITICAL):
-        with patch(
-            "gordo_dataset.sensor_tag._asset_from_tag_name",
-            side_effect=lambda *args, **kwargs: "default",
-        ):
-            out = runner.invoke(gordo_client, args=args)
+        out = runner.invoke(gordo_client, args=args)
 
     if should_fail:
         assert out.exit_code != 0, f"{out.output or out.exception}"
@@ -479,9 +454,9 @@ def test_exponential_sleep_time(caplog, gordo_project, ml_server):
     )
 
     with caplog.at_level(logging.CRITICAL):
-        with patch("gordo.client.client.sleep", return_value=None) as time_sleep:
+        with patch("gordo_client.client.sleep", return_value=None) as time_sleep:
             # We simulate repeating timeouts
-            with patch("gordo.client.client._handle_response") as handle_response_mock:
+            with patch("gordo_client.client._handle_response") as handle_response_mock:
                 handle_response_mock.side_effect = TimeoutError()
                 client = Client(project=gordo_project)
 
@@ -501,7 +476,7 @@ def test_exponential_sleep_time(caplog, gordo_project, ml_server):
 
 def test__handle_response_errors():
     """
-    Test expected error raising from gordo.client.io._handle_response
+    Test expected error raising from gordo_client.io._handle_response
     """
     resp = requests.Response()
     resp.status_code = 422
