@@ -133,26 +133,17 @@ def test_machine_from_config(default_globals: dict):
         "dataset": {
             "aggregation_methods": "mean",
             "asset": "global-asset",
-            "data_provider": {
-                "dl_service_auth_str": None,
-                "storage": None,
-                "assets_config": None,
-                "interactive": None,
-                "storename": None,
-                "type": "DataLakeProvider",
-            },
-            "default_asset": None,
+            "data_provider": None,
             "filter_periods": {"filter_method": "median", "window": 72, "n_iqr": 1},
             "high_threshold": 50000,
             "interpolation_limit": "8H",
             "interpolation_method": "linear_interpolation",
-            "known_filter_periods": [],
+            "known_filter_periods": None,
             "low_threshold": -1000,
             "n_samples_threshold": 0,
             "resolution": "10T",
             "row_filter": "",
             "row_filter_buffer_size": 0,
-            "tag_normalizer": "default",
             "tag_list": [
                 "GRA-TE  -23-0733.PV",
                 "GRA-TT  -23-0719.PV",
