@@ -20,6 +20,7 @@ from gordo.workflow.workflow_generator.workflow_generator import (
 )
 from gordo.util.version import GordoRelease, GordoSpecial, GordoPR, GordoSHA, Special
 from gordo_dataset import sensor_tag
+from typing import List
 
 
 logger = logging.getLogger(__name__)
@@ -34,14 +35,14 @@ def path_to_config_files():
 
 
 def _generate_test_workflow_yaml(
-    path_to_config_files, config_filename, project_name="test-proj-name"
+    path_to_config_files, config_filename, project_name="test-proj-name", args=None
 ):
     """
     Reads a test-config file with workflow_generator, and returns the parsed
     yaml of the generated workflow
     """
     getvalue = _generate_test_workflow_str(
-        path_to_config_files, config_filename, project_name=project_name
+        path_to_config_files, config_filename, project_name=project_name, args=args
     )
     expanded_template = yaml.load(getvalue, Loader=yaml.FullLoader)
 
@@ -49,14 +50,14 @@ def _generate_test_workflow_yaml(
 
 
 def _generate_test_workflow_str(
-    path_to_config_files, config_filename, project_name="test-proj-name"
+    path_to_config_files, config_filename, project_name="test-proj-name", args=None
 ):
     """
     Reads a test-config file with workflow_generator, and returns the string
     content of the generated workflow
     """
     config_file = os.path.join(path_to_config_files, config_filename)
-    args = [
+    cli_args = [
         "workflow",
         "generate",
         "--machine-config",
@@ -64,10 +65,11 @@ def _generate_test_workflow_str(
         "--project-name",
         project_name,
     ]
+    if args:
+        cli_args.extend(args)
     runner = CliRunner()
 
-    with patch.object(sensor_tag, "_asset_from_tag_name", return_value="default"):
-        result = runner.invoke(cli.gordo, args)
+    result = runner.invoke(cli.gordo, cli_args)
 
     if result.exception is not None:
         raise result.exception
@@ -152,8 +154,7 @@ def test_basic_generation(path_to_config_files):
         os.path.join(path_to_config_files, config_filename)
     )
 
-    with patch.object(sensor_tag, "_asset_from_tag_name", return_value="default"):
-        machines = NormalizedConfig(yaml_content, project_name=project_name).machines
+    machines = NormalizedConfig(yaml_content, project_name=project_name).machines
 
     assert len(machines) == 2
 
@@ -183,8 +184,7 @@ def test_generation_to_file(tmpdir, path_to_config_files):
         outfile,
     ]
     runner = CliRunner()
-    with patch.object(sensor_tag, "_asset_from_tag_name", return_value="default"):
-        result = runner.invoke(cli.gordo, args)
+    result = runner.invoke(cli.gordo, args)
     assert result.exit_code == 0
 
     # Open the file and ensure they are the same
@@ -244,6 +244,75 @@ def test_overrides_builder_datasource(path_to_config_files):
     )["dataset"]["data_provider"]
 
 
+def test_builder_labels(path_to_config_files):
+    expanded_template = _generate_test_workflow_yaml(
+        path_to_config_files, "config-test-runtime-labels.yaml"
+    )
+    templates = expanded_template["spec"]["templates"]
+    model_builder_task = [
+        task for task in templates if task["name"] == "model-builder"
+    ][0]
+    assert "key1" in model_builder_task["metadata"]["labels"]
+    assert "value1" == model_builder_task["metadata"]["labels"]["key1"]
+
+    assert "key2" in model_builder_task["metadata"]["labels"]
+    assert "2" == model_builder_task["metadata"]["labels"]["key2"]
+
+    assert "key3/withslash" in model_builder_task["metadata"]["labels"]
+    assert "value3" == model_builder_task["metadata"]["labels"]["key3/withslash"]
+
+    assert "key4/withslash.dot" in model_builder_task["metadata"]["labels"]
+    assert "value4" == model_builder_task["metadata"]["labels"]["key4/withslash.dot"]
+
+
+def filter_keys(input_list: list, key: str, values: List[str]) -> list:
+    output_list = []
+    for v in input_list:
+        find_v = v[key]
+        if find_v in values:
+            output_list.append(v)
+    return output_list
+
+
+@pytest.mark.parametrize(
+    "template_name,spec_key",
+    [("model-builder", "container"), ("gordo-client", "script")],
+)
+def test_model_builder_spec(path_to_config_files, template_name, spec_key):
+    expanded_template = _generate_test_workflow_yaml(
+        path_to_config_files, "config-test-model-builder-spec.yaml"
+    )
+    templates = expanded_template["spec"]["templates"]
+    volumes = expanded_template["spec"]["volumes"]
+    template = [task for task in templates if task["name"] == template_name][0]
+    labels = template["metadata"]["labels"]
+    env = template[spec_key]["env"]
+    volume_mounts = template[spec_key]["volumeMounts"]
+    assert labels["key1"] == "value1"
+    assert labels["key2"] == "value2"
+    assert filter_keys(env, "name", ["DL_PWD"]) == [
+        {
+            "name": "DL_PWD",
+            "valueFrom": {
+                "secretKeyRef": {"key": "deltalake-pwd", "name": "deltalake-pwd"}
+            },
+        }
+    ]
+    assert filter_keys(volumes, "name", ["secrets-store"]) == [
+        {
+            "csi": {
+                "driver": "secrets-store.csi.k8s.io",
+                "readOnly": True,
+                "volumeAttributes": {"secretProviderClass": "kv-sync"},
+            },
+            "name": "secrets-store",
+        }
+    ]
+    assert filter_keys(volume_mounts, "name", ["secrets-store"]) == [
+        {"mountPath": "/kvmnt", "name": "secrets-store", "readOnly": True}
+    ]
+
+
 def test_runtime_image_override(path_to_config_files):
     expanded_template = _generate_test_workflow_yaml(
         path_to_config_files, "config-test-runtime-images.yaml"
@@ -403,33 +472,6 @@ def test_selective_influx(path_to_config_files):
     assert client_tasks == ["gordo-client-ct-23-0002"]
 
 
-@pytest.mark.parametrize("output_to_file", (True, False))
-def test_main_tag_list(output_to_file, path_to_config_files, tmpdir):
-    config_file = os.path.join(path_to_config_files, "config-test-tag-list.yml")
-    args = ["workflow", "unique-tags", "--machine-config", config_file]
-
-    out_file = os.path.join(tmpdir, "out.txt")
-
-    if output_to_file:
-        args.extend(["--output-file-tag-list", out_file])
-
-    runner = CliRunner()
-    with patch.object(sensor_tag, "_asset_from_tag_name", return_value="default"):
-        result = runner.invoke(cli.gordo, args)
-
-    assert result.exit_code == 0
-
-    if output_to_file:
-        assert os.path.isfile(out_file)
-    else:
-        output_tags = set(result.output.split(sep="\n")[:-1])
-        expected_output_tags = {"Tag 1", "Tag 2", "Tag 3", "Tag 4", "Tag 5"}
-
-        assert (
-            output_tags == expected_output_tags
-        ), f"Expected to find: {expected_output_tags}, outputted {output_tags}"
-
-
 def test_valid_dateformats(path_to_config_files):
     output_workflow = _generate_test_workflow_str(
         path_to_config_files, "config-test-allowed-timestamps.yml"
@@ -561,3 +603,70 @@ def test_expected_models_in_workflow(repo_dir):
 def test_default_image_pull_policy(gordo_version, expected):
     result = default_image_pull_policy(gordo_version)
     assert result == expected
+
+
+def _get_names_recursively(steps: list) -> list:
+    names = []
+    for step in steps:
+        if type(step) is list:
+            names.extend(_get_names_recursively(step))
+        else:
+            names.append(step["name"])
+    return names
+
+
+@pytest.mark.parametrize(
+    "args,expected_steps",
+    [
+        ([], ["gordo-server-hpa"]),
+        (["--with-keda"], ["gordo-server-hpa", "gordo-server-keda-cleanup"]),
+        (["--ml-server-hpa-type", "none"], ["gordo-server-hpa-cleanup"]),
+        (
+            ["--with-keda", "--ml-server-hpa-type", "none"],
+            ["gordo-server-keda-cleanup", "gordo-server-hpa-cleanup"],
+        ),
+        (["--ml-server-hpa-type", "k8s_cpu"], ["gordo-server-hpa"]),
+        (
+            ["--with-keda", "--ml-server-hpa-type", "k8s_cpu"],
+            ["gordo-server-hpa", "gordo-server-keda-cleanup"],
+        ),
+        (
+            [
+                "--with-keda",
+                "--ml-server-hpa-type",
+                "keda",
+                "--prometheus-server-address",
+                "http://prometheus.local",
+            ],
+            ["gordo-server-keda", "gordo-server-hpa-cleanup"],
+        ),
+    ],
+)
+def test_hpa_types(path_to_config_files: str, args: list, expected_steps: list):
+    workflow_str = _generate_test_workflow_str(
+        path_to_config_files, "config-test-simple.yml", args=args
+    )
+    workflow = yaml.safe_load(workflow_str)
+    templates = workflow["spec"]["templates"]
+    gordo_server_step = [step for step in templates if step["name"] == "gordo-server"][
+        0
+    ]
+    names = _get_names_recursively(gordo_server_step["steps"])
+    for expected_step in expected_steps:
+        assert expected_step in names, (
+            "Unable to found expected gordo-server step '%s' with args: %s"
+            % (expected_step, " ".join(args))
+        )
+
+
+def test_with_resources_labels(path_to_config_files: str):
+    resources_labels = '{"some_custom_label": "value"}'
+    args = ["--resources-labels", resources_labels]
+    workflow_str = _generate_test_workflow_str(
+        path_to_config_files, "config-test-simple.yml", args=args
+    )
+    yaml.safe_load(workflow_str)
+    expected_str = '"some_custom_label": "value"'
+    assert workflow_str.find(
+        expected_str
+    ), 'Unable to find label "some_custom_label" in the generated argo-workflow'
